@@ -40,7 +40,7 @@ from prompt_toolkit.key_binding import (
     merge_key_bindings,
 )
 def modify_and_import(module_name, package, modification_func):
-    import importlib
+    import importlib.util
     import sys
     spec = importlib.util.find_spec(module_name, package)
     source = spec.loader.get_source(module_name)
